#!/usr/bin/env python3
from urllib import request


def setHeaders(url):
    if (url.split("//")[0] == "https:"):
        opener = request.build_opener()
        opener.addheaders = [('User-agent',
                              'Mozilla/5.0 (Macintosh; '
                              'Intel Mac OS X 10_9_3) '
                              'AppleWebKit/537.36(KHTML, like Gecko) '
                              'Chrome/35.0.1916.47 '
                              'Safari/537.36')]
        request.install_opener(opener)



#!/usr/bin/env python3
import os


def storagePath(url):
    url = url.split("//")[1]
    folderName = url.split("/")[0]
    dirPath = '/tmp/' + folderName

    if not os.path.exists(dirPath):
        os.mkdir(dirPath)

    return dirPath



#!/usr/bin/env python3
import logging


def initilaizeLog():
    logfile = '/tmp/downloadpdf.log'
    log_format = (
        '[%(asctime)s] %(levelname)-8s %(name)-12s '
        '%(message)s')

    logging.basicConfig(
        level=logging.INFO,
        format=log_format,
        filename=logfile
    )



#!/usr/bin/env python3
import re


def validateURL(url):
    regex = re.compile(
        r'^https?://'  # http:// or https://
        # domain...
        r'(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+[A-Z]{2,6}\.?|'
        r'localhost|'  # localhost...
        r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})'  # ...or ip
        r'(?::\d+)?'  # optional port
        r'(?:/?|[/?]\S+)$', re.IGNORECASE)

    if (regex.search(url) is None or url is None):
        raise Exception('Invalid URL!')



#!/usr/bin/env python3
import argparse


def setUpCLI():
    parser = argparse.ArgumentParser(
        description='Download PDFs from URL.')
    parser.add_argument('url', metavar='url',
                        type=str, help='URL, i.e. http://google.com')
    return parser.parse_args()



#!/usr/bin/env python3
import logging
from util.cli import setUpCLI
from util.storage import storagePath
from util.log import initilaizeLog
from util.url import validateURL
from util.header import setHeaders
from main.download import downloadPDF
from main.scrap import scrapHREF

try:
    args = setUpCLI()
    initilaizeLog()
    validateURL(args.url)
    location = storagePath(args.url)
    setHeaders(args.url)
    pdfs = scrapHREF(args.url)

    downloadPDF(args.url, location, pdfs)

except Exception as e:
    logging.error(e)

